aboutsummaryrefslogtreecommitdiffhomepage
path: root/cmd/sharefs/fuse-operations.h
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/sharefs/fuse-operations.h')
-rw-r--r--cmd/sharefs/fuse-operations.h7
1 files changed, 2 insertions, 5 deletions
diff --git a/cmd/sharefs/fuse-operations.h b/cmd/sharefs/fuse-operations.h
index edcfb2a7..da118c84 100644
--- a/cmd/sharefs/fuse-operations.h
+++ b/cmd/sharefs/fuse-operations.h
@@ -13,11 +13,8 @@
/* sharefs_private is populated by sharefs_init and contains process-wide context */
struct sharefs_private {
- int dirfd; /* source dirfd opened during sharefs_init */
- bool init_failed; /* whether sharefs_init failed */
- uintptr_t source_handle; /* cgo handle of pathname to open for dirfd, freed during sharefs_init */
- uintptr_t setuid; /* uid to set by sharefs_init when running as root */
- uintptr_t setgid; /* gid to set by sharefs_init when running as root */
+ int dirfd; /* source dirfd opened during sharefs_init */
+ uintptr_t setup; /* cgo handle of opaque setup state */
};
int sharefs_getattr(const char *pathname, struct stat *statbuf, struct fuse_file_info *fi);